Represents an error with the transport used by an HTTP connection.
This is a standardised exception that all Req adapters should use for transport-layer-related errors.
This exception is based on Mint.TransportError.
Represents an error with the transport used by an HTTP connection.
This is a standardised exception that all Req adapters should use for transport-layer-related errors.
This exception is based on Mint.TransportError.